#ifndef KBLINSELSTEREOGRAM_H
#define KBLINSELSTEREOGRAM_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif 

#include <stdlib.h>
#include <kapp.h>
#include <qwidget.h>
#include <qlabel.h>
#include <qimage.h>
#include <qpixmap.h>
#include <qstring.h>

#include "deiminger.h"


class KBlinselStereogram : public QWidget
{
	Q_OBJECT
public:
	KBlinselStereogram();
	virtual ~KBlinselStereogram();

	QImage calc();	

	void setTexture(QImage &texture);
	void setSource(QImage &img);
	void setMaxDistance(double maxDist);
        void init_stg();
        void init_field();
        void init_texture();
        
        bool use_texturing;
        float depf, mdu;
        float **Z;
        int maxX, maxY, textX, textY, maxsep;
        int **texture;
        QImage img1;
 
public slots:

signals:
	void renderStatus(int);

private:
	QImage source,pattern;
	
};

#endif // KBLINSELSTEREOGRAM_H
